#########################################
Factorization (``methods.factorization``)
#########################################

.. automodule:: nimfa.methods.factorization
	:members:
	:undoc-members:
	:inherited-members:
	:show-inheritance:	


.. toctree::
   :maxdepth: 2

   nimfa.methods.factorization.bd
   
   nimfa.methods.factorization.bmf
   
   nimfa.methods.factorization.icm
   
   nimfa.methods.factorization.lfnmf
   
   nimfa.methods.factorization.lsnmf
   
   nimfa.methods.factorization.nmf
   
   nimfa.methods.factorization.nsnmf
   
   nimfa.methods.factorization.pmf
   
   nimfa.methods.factorization.psmf
   
   nimfa.methods.factorization.snmf
   
   nimfa.methods.factorization.snmnmf
   
   nimfa.methods.factorization.pmfcc

   nimfa.methods.factorization.sepnmf
